action — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »

# action

The action module contains various QAction classes, representing commands that can be invoked via menus, toolbar buttons, and keyboard shortcuts.

class `camelot.view.action.` `ActionFactory`

  Utility class to generate some default actions we need in several places.

  Each method of this class, returns a certain action with a default text, icon and shortcut.

  classmethod `create_action`(*a, **kw)

    creates and returns a QAction object

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »

Comments
blog comments powered by Disqus